# Markdown Table Basics
From [PHP Markdown Extra](https://michelf.ca/projects/php-markdown/extra/)

## Simple
```markdown
First Header  | Second Header
------------- | -------------
Content Cell  | Content Cell
Content Cell  | Content Cell
```
```html
<table>
<thead>
<tr>
<th>First Header</th>
<th>Second Header</th>
</tr>
</thead>
<tbody>
<tr>
<td>Content Cell</td>
<td>Content Cell</td>
</tr>
<tr>
<td>Content Cell</td>
<td>Content Cell</td>
</tr>
</tbody>
</table>
```

## Leading and Tailing pipes
```markdown
| First Header  | Second Header |
| ------------- | ------------- |
| Content Cell  | Content Cell  |
| Content Cell  | Content Cell  |
```
```html
<table>
<thead>
<tr>
<th>First Header</th>
<th>Second Header</th>
</tr>
</thead>
<tbody>
<tr>
<td>Content Cell</td>
<td>Content Cell</td>
</tr>
<tr>
<td>Content Cell</td>
<td>Content Cell</td>
</tr>
</tbody>
</table>
```

## Alignments
```markdown
| Item      | Value |
| :-------: | -----:|
| Computer  | $1600 |
| Phone     |   $12 |
| Pipe      |    $1 |
```
```html
<table>
<thead>
<tr>
<th style="text-align:center">Item</th>
<th style="text-align:right">Value</th>
</tr>
</thead>
<tbody>
<tr>
<td style="text-align:center">Computer</td>
<td style="text-align:right">$1600</td>
</tr>
<tr>
<td style="text-align:center">Phone</td>
<td style="text-align:right">$12</td>
</tr>
<tr>
<td style="text-align:center">Pipe</td>
<td style="text-align:right">$1</td>
</tr>
</tbody>
</table>
```

## Span-level Formatting
```markdown
| Function name | Description                    |
| ------------- | ------------------------------ |
| `help()`      | Display the help window.       |
| `destroy()`   | **Destroy your computer!**     |
```
```html
<table>
<thead>
<tr>
<th>Function name</th>
<th>Description</th>
</tr>
</thead>
<tbody>
<tr>
<td><code>help()</code></td>
<td>Display the help window.</td>
</tr>
<tr>
<td><code>destroy()</code></td>
<td><strong>Destroy your computer!</strong></td>
</tr>
</tbody>
</table>
```
